use std::process::Command;
use rocket::serde::json::{serde_json};
use rocket::serde::{Serialize, Deserialize};

#[derive(Serialize)]
#[serde(crate = "rocket::serde")]
pub struct Disk {
    name: String,
    size: u64,
}

#[derive(Serialize, Deserialize)]
#[serde(crate = "rocket::serde")]
struct ChildDevice {
    name: String,
    #[serde(rename = "maj:min")]
    majmin: String,
    rm: bool,
    size: u64,
    ro: bool,
    #[serde(rename = "type")]
    kind: String,
    mountpoints: Vec<Option<String>>,
}

#[derive(Serialize, Deserialize)]
#[serde(crate = "rocket::serde")]
struct Blockdevice {
    name: String,
    #[serde(rename = "type")]
    kind: String,
    size: u64,
    #[serde(rename = "maj:min")]
    majmin: String,
    rm: bool,
    ro: bool,
    mountpoints: Vec<Option<String>>,
    children: Option<Vec<ChildDevice>>,
}

#[derive(Serialize, Deserialize)]
#[serde(crate = "rocket::serde")]
struct LsblkT {
    blockdevices: Vec<Blockdevice>,
}

pub fn parse_lsblk() -> Vec<Disk> {
    let output = Command::new("lsblk")
        .arg("-J")
        .arg("-b")// sizes in bytes
        .arg("-p") // complete device path
        .output()
        .expect("failed to execute process");

    let out = output.stdout;
    let out = String::from_utf8(out).unwrap();

    let v: LsblkT = serde_json::from_str(out.as_str()).unwrap();

    let mut disks: Vec<Disk> = Vec::new();
    for d in v.blockdevices {
        if d.kind != "disk" { continue; };
        disks.push(Disk { name: d.name, size: d.size });
    }
    return disks;
}
